@@ -6,6 +6,7 @@ from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
 import functools
+import os
 import ssl
 import sys
 import threading
@@ -31,6 +32,7 @@ from ..testing import (
 )
 
 
+IS_GITHUB_ACTIONS_WORKFLOW = bool(os.getenv('GITHUB_WORKFLOW'))
 IS_LIBRESSL_BACKEND = ssl.OPENSSL_VERSION.startswith('LibreSSL')
 IS_PYOPENSSL_SSL_VERSION_1_0 = (
     OpenSSL.SSL.SSLeay_version(OpenSSL.SSL.SSLEAY_VERSION).
@@ -49,13 +51,13 @@ _stdlib_to_openssl_verify = {
 
 
 fails_under_py3 = pytest.mark.xfail(
-    six.PY3,
-    reason='Fails under Python 3',
+    not six.PY2,
+    reason='Fails under Python 3+',
 )
 
 
 fails_under_py3_in_pypy = pytest.mark.xfail(
-    six.PY3 and IS_PYPY,
+    not six.PY2 and IS_PYPY,
     reason='Fails under PyPy3',
 )
 
@@ -318,7 +320,7 @@ def test_tls_client_auth(
         ) if PY34 else (
             requests.exceptions.SSLError,
         )
-        if IS_WINDOWS:
+        if IS_WINDOWS or IS_GITHUB_ACTIONS_WORKFLOW:
             expected_ssl_errors += requests.exceptions.ConnectionError,
         with pytest.raises(expected_ssl_errors) as ssl_err:
             make_https_request()
@@ -334,7 +336,7 @@ def test_tls_client_auth(
         except AttributeError:
             if PY34:
                 pytest.xfail('OpenSSL behaves wierdly under Python 3.4')
-            elif six.PY3 and IS_WINDOWS:
+            elif not six.PY2 and IS_WINDOWS:
                 err_text = str(ssl_err.value)
             else:
                 raise
@@ -343,7 +345,7 @@ def test_tls_client_auth(
             'sslv3 alert bad certificate' if IS_LIBRESSL_BACKEND
             else 'tlsv1 alert unknown ca',
         )
-        if six.PY3:
+        if not six.PY2:
             if IS_MACOS and IS_PYPY and adapter_type == 'pyopenssl':
                 expected_substrings = ('tlsv1 alert unknown ca', )
             if (
@@ -438,7 +440,7 @@ def test_http_over_https_error(
 
     expect_fallback_response_over_plain_http = (
         (adapter_type == 'pyopenssl'
-         and (IS_ABOVE_OPENSSL10 or six.PY3))
+         and (IS_ABOVE_OPENSSL10 or not six.PY2))
         or PY27
     )
     if expect_fallback_response_over_plain_http:
